@@ -96,7 +96,7 @@ def getlastshot():
     return nshot
 
 
-def get_ts06(nshot):
+def get_cti_ts06(nshot):
     """
     Gets the absolute time (ns) of a discharge trigger 
     """
@@ -160,6 +160,15 @@ class SFREAD:
         Opens a shotfile, reads the header
         """
 
+        self.shot = None
+        self.diag = None
+        self.exp = None
+        self.status = False
+        self.open(*args, **kwargs)
+
+
+    def open(self, *args, **kwargs):
+
         n_args = len(args) 
         if n_args == 0:
             print('No argument given, need at least diag_name')
@@ -327,7 +336,7 @@ class SFREAD:
 
 # LongLong in [ns] and no zero at TS06
                 if otyp == 8 and dfmt == 13: # RMC:TIME-AD0
-                    dout = 1e-9*(data - get_ts06(self.shot))
+                    dout = 1e-9*(data - self.get_ts06())
                 else:
                     dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
                 if otyp in (6, 7) and cal:
@@ -502,3 +511,21 @@ class SFREAD:
         """
 
         return self.getparset(lbl)
+
+
+    def get_ts06(self):
+        """
+        Reads the diagnostic internal TS06 from parameter set
+        """
+        ts6 = 0
+        for obj in self.parsets:
+            if self.sfh[obj].obj_type == 3:
+                ps = self.getparset(obj)
+                if 'TS06' in ps.keys():
+                    ts6 = ps['TS06']
+                    break
+
+        if ts6 == 0:
+            ts6 = get_cti_ts06(self.shot)
+
+        return ts6
